<template>
  <div>
    <Echart
      :options="options"
      id="bottomLeftChart"
      height="480px"
      width="100%"
    ></Echart>
  </div>
</template>

<script>
import Echart from "@/common/echart";
export default {
  data() {
    return {
      options: {},
    };
  },
  components: {
    Echart,
  },
  props: {
    cdata: {
      type: Object,
      default: () => ({}),
    },
  },
  watch: {
    cdata: {
      handler(newData) {
        this.options = {
          title: {
            text: "",
          },
          tooltip: {
            trigger: "axis",
            backgroundColor: "rgba(255,255,255,0.1)",
            axisPointer: {
              type: "shadow",
              label: {
                show: true,
                backgroundColor: "#7B7DDC",
              },
            },
          },
          legend: {
            data: ["压机合格率", "测漏合格率"],
            textStyle: {
              color: "#fff",
              fontSize: 14,
            },
            top: "0%",
            right: "10",
          },
          grid: {
            x: "6%",
            width: "95%",
            bottom: "10%",
          },
          xAxis: {
            data: newData.category,
            axisLine: {
              lineStyle: {
                color: "#B4B4B4",
              },
            },
            splitLine: {
              show: true,
              lineStyle: {
                color: ["#273169"],
              },
            },
            axisTick: {
              show: false,
            },
          },
          calculable: true,
          yAxis: [
            {
              min: 60, // 刻度最小值
              max: 100, // 刻度最大值（需要动态获取最大值,并且能被3整除（向下取整再乘回来））
              splitNumber: 10, // 横线数
              interval: 10, // 刻度间隔
              splitLine: {
                show: true,
                lineStyle: {
                  color: ["#273169"],
                },
              },
              axisLine: {
                lineStyle: {
                  color: "#B4B4B4",
                },
              },
              axisLabel: {
                formatter: "{value} ",
              },
              name: "单位（%）",
              nameTextStyle: {
                color: "#ffffff",
                nameLocation: "start",
              },
            },
            {
              axisLine: {
                lineStyle: {
                  color: "#B4B4B4",
                },
              },
              axisLabel: {
                formatter: "{value} ",
              },
            },
          ],
          series: [
            {
              name: "压机合格率",
              type: "line",
              barWidth: 10,
              areaStyle: {
                color: {
                  type: "linear",
                  x: 0,
                  y: 0,
                  x2: 0,
                  y2: 1,
                  colorStops: [
                    {
                      offset: 0,
                      color: "rgba(220, 20, 60,0.5)",
                    },
                    {
                      offset: 0.6, //这是于下方线的距离,设置1就不留空隙
                      color: "rgba(220, 20, 60,0.1)",
                    },
                  ],
                  global: false,
                },
              },
              itemStyle: {
                normal: {
                  barBorderRadius: 2,
                  color: new this.$echarts.graphic.LinearGradient(0, 0, 0, 1, [
                    { offset: 0, color: "red" },
                    { offset: 1, color: "red" },
                  ]),
                  label: {
                    show: false, //开启显示
                    position: "top", //在上方显示
                    textStyle: {
                      //数值样式
                      color: "red",
                      fontSize: 16,
                    },
                    //添加后缀
                    formatter: function (params) {
                      return params.value + "%";
                    },
                  },
                },
              },
              data: newData.pressData,
            },
            {
              name: "测漏合格率",
              type: "line",
              barWidth: 10,
              areaStyle: {
                color: {
                  type: "linear",
                  x: 0,
                  y: 0,
                  x2: 0,
                  y2: 1,
                  colorStops: [
                    {
                      offset: 0,
                      color: "rgba(0,156,255,0.5)",
                    },
                    {
                      offset: 0.6,
                      color: "rgba(0,156,255,0.1)",
                    },
                  ],
                  global: false,
                },
              },
              itemStyle: {
                normal: {
                  barBorderRadius: 5,
                  color: new this.$echarts.graphic.LinearGradient(0, 0, 0, 1, [
                    { offset: 0, color: "#3EACE5" },
                    { offset: 1, color: "#3EACE5" },
                  ]),
                  label: {
                    show: false, //开启显示
                    position: "bottom", //在上方显示
                    textStyle: {
                      //数值样式
                      color: "white",
                      fontSize: 16,
                    },
                    //添加后缀
                    formatter: function (params) {
                      return params.value + "%";
                    },
                  },
                },
              },
              data: newData.sideData,
            },
          ],
        };
      },
      immediate: true,
      deep: true,
    },
  },
};
</script>